summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/config/accounts/kopeteaccountconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/config/accounts/kopeteaccountconfig.cpp')
-rw-r--r--kopete/kopete/config/accounts/kopeteaccountconfig.cpp48
1 files changed, 24 insertions, 24 deletions
diff --git a/kopete/kopete/config/accounts/kopeteaccountconfig.cpp b/kopete/kopete/config/accounts/kopeteaccountconfig.cpp
index 3d86fb8d..feaa88fd 100644
--- a/kopete/kopete/config/accounts/kopeteaccountconfig.cpp
+++ b/kopete/kopete/config/accounts/kopeteaccountconfig.cpp
@@ -18,9 +18,9 @@
#include "kopeteaccountconfig.h"
-#include <qcheckbox.h>
-#include <qlayout.h>
-#include <qguardedptr.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
+#include <tqguardedptr.h>
#include <kcolorbutton.h>
#include <kpushbutton.h>
@@ -47,31 +47,31 @@ class KopeteAccountLVI : public KListViewItem
private:
//need to be guarded because some accounts may be linked (that's the case of jabber transports)
- QGuardedPtr<Kopete::Account> m_account;
+ TQGuardedPtr<Kopete::Account> m_account;
};
-typedef KGenericFactory<KopeteAccountConfig, QWidget> KopeteAccountConfigFactory;
+typedef KGenericFactory<KopeteAccountConfig, TQWidget> KopeteAccountConfigFactory;
K_EXPORT_COMPONENT_FACTORY( kcm_kopete_accountconfig, KopeteAccountConfigFactory( "kcm_kopete_accountconfig" ) )
-KopeteAccountConfig::KopeteAccountConfig( QWidget *parent, const char * /* name */, const QStringList &args )
+KopeteAccountConfig::KopeteAccountConfig( TQWidget *parent, const char * /* name */, const TQStringList &args )
: KCModule( KopeteAccountConfigFactory::instance(), parent, args )
{
- ( new QVBoxLayout( this ) )->setAutoAdd( true );
+ ( new TQVBoxLayout( this ) )->setAutoAdd( true );
m_view = new KopeteAccountConfigBase( this, "KopeteAccountConfig::m_view" );
m_view->mButtonUp->setIconSet( SmallIconSet( "up" ) );
m_view->mButtonDown->setIconSet( SmallIconSet( "down" ) );
- connect( m_view->mButtonNew, SIGNAL( clicked() ), this, SLOT( slotAddAccount() ) );
- connect( m_view->mButtonEdit, SIGNAL( clicked() ), this, SLOT( slotEditAccount() ) );
- connect( m_view->mButtonRemove, SIGNAL( clicked() ), this, SLOT( slotRemoveAccount() ) );
- connect( m_view->mButtonUp, SIGNAL( clicked() ), this, SLOT( slotAccountUp() ) );
- connect( m_view->mButtonDown, SIGNAL( clicked() ), this, SLOT( slotAccountDown() ) );
- connect( m_view->mAccountList, SIGNAL( selectionChanged() ), this, SLOT( slotItemSelected() ) );
- connect( m_view->mAccountList, SIGNAL( doubleClicked( QListViewItem * ) ), this, SLOT( slotEditAccount() ) );
- connect( m_view->mUseColor, SIGNAL( toggled( bool ) ), this, SLOT( slotColorChanged() ) );
- connect( m_view->mColorButton, SIGNAL( changed( const QColor & ) ), this, SLOT( slotColorChanged() ) );
+ connect( m_view->mButtonNew, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAddAccount() ) );
+ connect( m_view->mButtonEdit, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotEditAccount() ) );
+ connect( m_view->mButtonRemove, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotRemoveAccount() ) );
+ connect( m_view->mButtonUp, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAccountUp() ) );
+ connect( m_view->mButtonDown, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotAccountDown() ) );
+ connect( m_view->mAccountList, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( slotItemSelected() ) );
+ connect( m_view->mAccountList, TQT_SIGNAL( doubleClicked( TQListViewItem * ) ), this, TQT_SLOT( slotEditAccount() ) );
+ connect( m_view->mUseColor, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( slotColorChanged() ) );
+ connect( m_view->mColorButton, TQT_SIGNAL( changed( const TQColor & ) ), this, TQT_SLOT( slotColorChanged() ) );
m_view->mAccountList->setSorting(-1);
@@ -92,7 +92,7 @@ void KopeteAccountConfig::save()
i = static_cast<KopeteAccountLVI*>( i->nextSibling() );
}
- QMap<Kopete::Account *, QColor>::Iterator it;
+ TQMap<Kopete::Account *, TQColor>::Iterator it;
for(it=m_newColors.begin() ; it != m_newColors.end() ; ++it)
it.key()->setColor(it.data());
m_newColors.clear();
@@ -108,7 +108,7 @@ void KopeteAccountConfig::load()
m_view->mAccountList->clear();
- QPtrList<Kopete::Account> accounts = Kopete::AccountManager::self()->accounts();
+ TQPtrList<Kopete::Account> accounts = Kopete::AccountManager::self()->accounts();
for ( Kopete::Account *i = accounts.first() ; i; i = accounts.next() )
{
// Insert the item after the previous one
@@ -136,7 +136,7 @@ void KopeteAccountConfig::slotItemSelected()
m_view->mButtonDown->setEnabled( itemSelected->itemBelow() );
Kopete::Account *account = itemSelected->account();
- QColor color= m_newColors.contains(account) ? m_newColors[account] : account->color();
+ TQColor color= m_newColors.contains(account) ? m_newColors[account] : account->color();
m_view->mUseColor->setEnabled( true );
m_view->mUseColor->setChecked( color.isValid() );
m_view->mColorButton->setColor( color );
@@ -181,7 +181,7 @@ void KopeteAccountConfig::slotAccountDown()
void KopeteAccountConfig::slotAddAccount()
{
AddAccountWizard *m_addwizard = new AddAccountWizard( this, "addAccountWizard", true );
- connect( m_addwizard, SIGNAL( destroyed( QObject * ) ), this, SLOT( slotAddWizardDone() ) );
+ connect( m_addwizard, TQT_SIGNAL( destroyed( TQObject * ) ), this, TQT_SLOT( slotAddWizardDone() ) );
m_addwizard->show();
}
@@ -204,15 +204,15 @@ void KopeteAccountConfig::slotEditAccount()
// FIXME: Why the #### is EditAccountWidget not a QWidget?!? This sideways casting
// is braindead and error-prone. Looking at MSN the only reason I can see is
// because it allows direct subclassing of designer widgets. But what is
// wrong with embedding the designer widget in an empty QWidget instead?
// Also, if this REALLY has to be a pure class and not a widget, then the
// class should at least be renamed to EditAccountIface instead - Martijn
- QWidget *w = dynamic_cast<QWidget *>( m_accountWidget );
+ TQWidget *w = dynamic_cast<TQWidget *>( m_accountWidget );
if ( !w )
return;
editDialog->setMainWidget( w );
- if ( editDialog->exec() == QDialog::Accepted )
+ if ( editDialog->exec() == TQDialog::Accepted )
{
if( m_accountWidget->validateData() )
m_accountWidget->apply();
@@ -263,7 +263,7 @@ void KopeteAccountConfig::slotColorChanged()
}
else if(!m_view->mUseColor->isChecked())
{ //the user disabled account coloring, but it was activated before
- m_newColors[account]=QColor();
+ m_newColors[account]=TQColor();
emit changed(true);
return;
}
@@ -204,15 +204,15 @@ void KopeteAccountConfig::slotEditAccount()
// is braindead and error-prone. Looking at MSN the only reason I can see is
// because it allows direct subclassing of designer widgets. But what is
- // wrong with embedding the designer widget in an empty QWidget instead?
+ // wrong with embedding the designer widget in an empty TQWidget instead?
// Also, if this REALLY has to be a pure class and not a widget, then the
// class should at least be renamed to EditAccountIface instead - Martijn